﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class GenerateText : MonoBehaviour
{
    public Transform PrefabMesh;
    public string Text;
    public Texture2D FontTexture;
    public float FontScale = .5f;
    public float MeshScale = 1.0f;
    public float TransitionTime = 1.0f;

    public bool CenteredX = true;

    private int CellWidth = 8;
    private int CellHeight = 8;

    private ArrayList Meshes = new ArrayList();

    void Awake()
    {
        Generate(Text);
    }
    
    void Generate(string text)
    {
        if (!enabled) return;   // 이 스크립트가 사용가능하지 않다면 리턴.
        
        ArrayList newMeshes = new ArrayList();
        Vector3 startPos = transform.position;

        if (CenteredX)
            startPos.x -= (text.Length * CellWidth * FontScale * 0.5f);
        startPos.y -= CellHeight * FontScale * 0.5f;

        for (int i = 0; i < text.Length; i++)
        {
            int c = -1;

            // 폰트 텍스쳐안의 문자들과 위치를 맞추기 위한 계산
            if (Text[i] >= 'A' && Text[i] <= 'Z')
            {
                c = System.Convert.ToInt16(Text[i]) - System.Convert.ToInt16('A');
            }
            else if (Text[i] >= '0' && Text[i] <= '9')
            {
                c = System.Convert.ToInt16(Text[i]) - System.Convert.ToInt16('0') + 26;
            }           

            if (c != -1)
            {
                // 현재 폰트 텍스쳐의 문자당 Width값이 8 픽셀이기 때문에..
                Color[] pixels = FontTexture.GetPixels(c * 8, 0, CellWidth, CellHeight);
                for (int x = 0; x < CellWidth; x++)
                {
                    for (int y = 0; y < CellHeight; y++)
                    {
                        if (pixels[(y * CellHeight) + x] == Color.black)
                        {
                            Transform mesh = (Transform)Instantiate(PrefabMesh, startPos + new Vector3(x * FontScale + (CellWidth * FontScale * i), y * FontScale, 0), Quaternion.identity);
                            mesh.gameObject.layer = gameObject.layer;
                            mesh.localScale = new Vector3(FontScale, FontScale, FontScale) * MeshScale;
                            newMeshes.Add(mesh);
                        }
                    }
                }
            }
        }
    }

}
